  /*
  Copyright (C) 2017 SAS Institute Inc. Cary, NC, USA
*/
/**
   \file     
   \brief   Macro calculates cardinality for instrument tables based on user-specified 
            number of partitions
            
    
   <b> Identified Inputs </b>

    \param[in] IN_DS                   Input data set that needs the partition
    \param[in] IN_BYN                  Input configuration data set pf number of partitions
       
   <b> Identified Outputs </b>

    \param[out] OUT_CARD_DS            Output cardinality table.
    
 
     The table OUT_CARD_DS has the following lay-out:
     
    |          Variable                  | Type     | Expected contents                                                  |
    |------------------------------------|----------|--------------------------------------------------------------------|
    | MAX_RANK_NO                        | num      | Maximum ranking number                                             |

    \ingroup data_prep
     
    \author  SAS Institute Inc.
    
    \date    2017

    
   */

%macro irm_get_cardinality_byn (IN_DS=,
                                IN_BYN=,
                                OUT_CARD_DS=,
                                );

   %rsk_trace(ENTRY);
   
   /*******check if the input configuration data is empty, if empty, MAX_RANK_NO=1********************/
   %if %rsk_attrn(&IN_BYN.,NOBS) eq 0 %then %do;
    
      %rsk_print_msg(key=irm_partition_byn_configuration_empty,s1=&IN_BYN.);
   
      data &OUT_CARD_DS.;
         MAX_RANK_NO=1;
      run;
      
   %end;
   
   %else %do; 
   
      /*******check if the input data to be partitioned is empty, if empty, create the empty cardinality table and empty mapping table********************/
      %if %rsk_attrn(&IN_DS.,NOBS) eq 0 %then %do;

         %rsk_print_msg(key=irm_empty_input_data_for_partition,s1=&IN_DS.);

         data &OUT_CARD_DS.;
            MAX_RANK_NO=1;
         run;

      %end;
      %else %do;
         /* Get the max rank of partitions */
          data null;
             set &IN_BYN.;
             call symput('partition_no', trim(left(MAX_RANK_NO)));
          run;
          
          proc sql noprint;
             select count(*) into :obs_num
             from &IN_DS.;
          quit;
      
          %if &obs_num.<&partition_no. %then %do;
          
             %rsk_print_msg(key=irm_byn_no_too_large,s1=&IN_BYN.,s2=&IN_DS.);
             
             data &OUT_CARD_DS.;
                MAX_RANK_NO=&obs_num.;
             run;
             
          %end;
          %else %do;
          
             data &OUT_CARD_DS.;
                set &IN_BYN.;
             run;
             
          %end;
          
      %end;

   %end;
   
   %rsk_trace(EXIT);
   
%mend irm_get_cardinality_byn;
