/*
 Copyright (C) 2017 SAS Institute Inc. Cary, NC, USA
*/

/**
   \file
   \brief The macro irm_recombine_byn.sas stacks the set of partitioned tables into one non-partitioned table.
   
   \details 
       
   <b> Identified Inputs </b>
   
   The following inputs are required by this macro:
      \param[in] IN_DS_NM             The table name of the input partitioned data sets
      \param[in] LIB_PREFIX           The library prefix of the input libraries when appending partitioned tables
      \param[in] PARTITON_NO          Number of partitions

   <b> Identified Outputs</b>
    
      \param[out]   O_DS             non-partitioned table output

      The table O_DS has the same structure as the input table IN_DS_NM
    
   \ingroup Utility
    \author SAS Institute INC.
    \date 2017
    
 */
 
 
%macro irm_recombine_byn(IN_DS_NM = ,
                     LIB_PREFIX = ,
                     PARTITION_NO = ,
                     O_DS = );
                     
   %local i table_nm;
    %if %irm_wordcount(&IN_DS_NM,dlm=%str(.))=2 %then %do;
         %let table_nm=%scan(&IN_DS_NM,2);
    %end;
    %else %do;
         %let table_nm=&IN_DS_NM;
    %end;
   
   /* Stack partitioned data sets into one. */
   data &O_DS;
      set
         %do i=1 %to &PARTITION_NO;
            &LIB_PREFIX.&i..&table_nm 
         %end;
         ; 
   run;

%mend;
